summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/channels.h2
-rw-r--r--include/messages.h5
2 files changed, 4 insertions, 3 deletions
diff --git a/include/channels.h b/include/channels.h
index adecb4701..c3eae003f 100644
--- a/include/channels.h
+++ b/include/channels.h
@@ -215,7 +215,7 @@ public:
* @param mode the modes
* @param enforce_mlock true to enforce mlock
*/
- void SetModesInternal(MessageSource &source, const Anope::string &mode, time_t ts = 0, bool enforce_mlock = true);
+ void SetModesInternal(MessageSource &source, const Anope::string &modes, const std::vector<Anope::string> &params, time_t ts = 0, bool enforce_mlock = true);
/** Does the given user match the given list? (CMODE_BAN, CMODE_EXCEPT, etc, a list mode)
* @param u The user
diff --git a/include/messages.h b/include/messages.h
index 59e483923..ea0a174b6 100644
--- a/include/messages.h
+++ b/include/messages.h
@@ -66,10 +66,11 @@ namespace Message
* @param source The source of the SJOIN
* @param chan The channel the users are joining to
* @param ts The TS for the channel
* @param modes The modes sent with the SJOIN, if any
* @param users The users and their status, if any
*/
- static void SJoin(MessageSource &source, const Anope::string &chan, time_t ts, const Anope::string &modes, const std::list<SJoinUser> &users);
+ static void SJoin(MessageSource &source, const Anope::string &chan, time_t ts, const Anope::string &modes, const std::vector<Anope::string> &modeparams, const std::list<SJoinUser> &users);
};
struct CoreExport Kick
@@ -66,10 +66,11 @@ namespace Message
* @param chan The channel the users are joining to
* @param ts The TS for the channel
- * @param modes The modes sent with the SJOIN, if any
+ * @param modes The mode letters sent with the SJOIN, if any
+ * @param modeparams The mode parameters sent with the SJOIN, if any
* @param users The users and their status, if any
*/